{ inputs, config, lib, pkgs, modulesPath, ... }:

{
  imports = [
    inputs.hardware.nixosModules.common-pc-ssd
    inputs.hardware.nixosModules.common-pc

    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  # use better power management for a device that's always on
  powerManagement.cpuFreqGovernor = lib.mkDefault "ondemand";

  # i have a couple others i don't noramlly include, such as:
  # uas (uasp, scsi over usb), usbcore (needed(???) for the drive at boot)
  # pcie_brcmstb (required for pcie), reset-raspberrypi (needed for vl805 firmware to load)
  boot.initrd.availableKernelModules = [ "xhci_pci" "ehci_pci" "ahci" "pcie_brcmstb" "reset-raspberrypi" "uas" "usbcore" "usbhid" "usb_storage" "sd_mod" "sdhci_pci" ];
  boot.initrd.kernelModules = [ ];
  boot.kernelModules = [ ];
  boot.extraModulePackages = [ ];

  # for some god forsaken reason, generic-extlinux-compatible doesn't disable grub like systemd-boot does
  boot.loader.grub.enable = false;
  boot.loader.generic-extlinux-compatible.enable = true;

  # needed for initial framebuffer logs to appear on raspberry pi
  # i think. this fixes it but idk if they are all required
  boot.kernelParams = [ 
    "8250.nr_uarts=1"
    "cma=128M"
    "console=tty0"
  ];

  fileSystems."/" =
    { device = "/dev/disk/by-uuid/04542424-6899-4b94-9414-fffa569f2c03";
      fsType = "ext4";
      options = [ "noatime" "nodiratime" "discard" ];
    };

  # Enables DHCP on each ethernet and wireless interface. In case of scripted networking
  # (the default) this is the recommended approach. When using systemd-networkd it's
  # still possible to use this option, but it's recommended to use it in conjunction
  # with explicit per-interface declarations with `networking.interfaces.<interface>.useDHCP`.
  networking.useDHCP = lib.mkDefault true;
  # networking.interfaces.end0.useDHCP = lib.mkDefault true;
  # networking.interfaces.wlan0.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "aarch64-linux";
}
